#!/bin/sh
###############################################################################
#
#   Genesis CDROM Installation Script
#
#   Created on:  07/10/1997 By Brian C. Watson for GENESIS v4.0
#   Modified on: 10/07/1998 By Brian C. Watson for GENESIS v5.0
#   Modified on: 01/27/2000 By Brian C. Watson for GENESIS v6.0
#   Modified on: 2001-06-12 By Brian C. Watson for GENESIS  7.0
#   Modified on: 2002-11-01 By Brian C. Watson for GENESIS  7.2
#   Modified on: 2003-03-25 By Brian C. Watson for GENESIS  7.2.1
#   Modified on: 2003-04-18 By Brian C. Watson for GENESIS  7.3
#   Modified on: 2004-03-03 By Brian C. Watson for GENESIS  7.5
#   Modified on: 2005-10-11 By Brian C. Watson for GENESIS  8.0
#   Modified on: 2006-08-25 By Brian C. Watson for GENESIS  9.0
#   Modified on: 2008-05-02 By Brian C. Watson for GENESIS 10.0
#   Modified on: 2008-11-19 By Brian C. Watson for GENESIS 10.1
#   Modified on: 2009-05-18 By Brian C. Watson for GENESIS 11.0
#
###############################################################################
GENVER=11.0
GENDIR=gen110
#
#  remember location of installation files
#
FROMDIR=`dirname $0`
if [ "$FROMDIR" = "." ]; then
   FROMDIR=`pwd`
elif [ `expr $FROMDIR : '\(.\).*'` != '/' ]; then
   FROMDIR=`pwd`/$FROMDIR
fi
PATH=/usr/bin:/bin:/usr/sbin:/sbin:/usr/bsd
export PATH
for file in $FROMDIR/* $FROMDIR/unix/* $FROMDIR/UNIX/*
do
   if [ -f "$file" ]; then
      case "$file" in
         */insdt.dsh*|*/INSDT.DSH*) GUIINSTALL="$file"
            ;;
         */license.txt*|*/LICENSE.TXT*) LICFILE="$file"
            ;;
         */gensun.tz*|*/GENSUN.TZ*) GENSUN="$file"
            ;;
         */gensgi.tz*|*/GENSGI.TZ*) GENSGI="$file"
            ;;
         */genhp.tz*|*/GENHP.TZ*) GENHP="$file"
            ;;
         */genhpi.tz*|*/GENHPI.TZ*) GENHPI="$file"
            ;;
         */genibm.tz*|*/GENIBM.TZ*) GENIBM="$file"
            ;;
         */genlnx.tz*|*/GENLNX.TZ*) GENLNX="$file"
            ;;
         */genlnx32.tz*|*/GENLNX32.TZ*) GENLNX32="$file"
            ;;
         */genatx.tz*|*/GENATX.TZ*) GENATX="$file"
            ;;
         */genmi.tz*|*/GENMI.TZ*) GENMI="$file"
            ;;
         */dsgmi.tz*|*/DSGMI.TZ*) DSGMI="$file"
            ;;
         */dsgsun.tz*|*/DSGSUN.TZ*) DSGSUN="$file"
            ;;
         */dsghp.tz*|*/DSGHP.TZ*) DSGHP="$file"
            ;;
         */dsglnx.tz*|*/DSGLNX.TZ*) DSGLNX="$file"
            ;;
         */dsgibm.tz*|*/DSGIBM.TZ*) DSGIBM="$file"
            ;;
         */gengrey.xpm*|*/GENGREY.XPM*) GENPIXMAP="$file"
            ;;
         */rung.tpl*|*/RUNG.TPL*) RUNG="$file"
            ;;
         */dsg.tpl*|*/DSG.TPL*) DSG="$file"
            ;;
         */gendns.tz*|*/GENDNS.TZ*) GENDNS="$file"
            ;;
         */dns2dat.tpl*|*/DNS2DAT.TPL*) DNS2DAT="$file"
            ;;
         */lmu.tpl*|*/LMU.TPL*) LMU="$file"
            ;;
         */lmg.tpl*|*/LMG.TPL*) LMG="$file"
            ;;
         */flexlm.tz*|*/FLEXLM.TZ*) FLEXLM="$file"
            ;;
      esac
   elif [ -d "$file" ]; then
      case "$file" in
         */manuals|*/MANUALS) MANDIR="$file"
            ;;
         */acrobat|*/ACROBAT) ACRODIR="$file"
            ;;
      esac
   fi
done
#
INSSCRIPT=`basename $0`
Usage() {
   printf "Usage: $FROMDIR/$INSSCRIPT [-gui]
        Install GENESIS ${GENVER} and/or Design Studio for Genesis ${GENVER}.
        -gui    Try to use the graphical install tool.\n" >&2
}
#
NOGUI=1
while [ $# != 0 ];
do
   case "$1" in
      -gui) NOGUI=0;;
      *) Usage; exit 1;;
   esac
   shift
done
# OSF1 dtksh is broken
case `uname` in
   OSF1) NOGUI=1;;
esac
if [ x"$NOGUI" != x1 ]; then
   if [ -x /usr/dt/bin/dtksh -a -x "$GUIINSTALL" ]; then
      exec "$GUIINSTALL"
   fi
fi
#
###############################################################################
#
# Function: Banner
#
# Purpose: print a banner message
#
# Notes:  
#
###############################################################################
Banner() {
clear
printf "\n
                GENESIS ${GENVER} Workstation/Server Installation
\n\n"
}
###############################################################################
#
# Function: GetYesNo
#
# Purpose: prompt the user to enter yes or no
#
# Notes:   Sets ANS to "YES" or "NO"
#
###############################################################################
GetYesNo() {
   ANS=""
   while [ "x$ANS" = "x" ]; do
      printf "
   (y) Yes 
   (n) No
?"
      read ans
      case "$ans" in
         y|yes|Y|YES) return 0
            ;;
         n|no|N|NO) return 1
            ;;
         *) printf ""
            ;;
      esac
   done
}
###############################################################################
#
# Function: PressReturn
#
# Purpose: prompt the user to press return to continue
#
# Notes:   
#
###############################################################################
PressReturn() {
   printf "\nPress RETURN to continue"
   read ans
}
###############################################################################
#
# Function: DeTar
#
# Purpose: Untar a package
#
# Notes:   
#
###############################################################################
DeTar() {
      if [ ! -f "$1" ]; then
         printf "" >&2
         printf "\n\nError: Cannot locate the $2 files.
       Installation aborted.\n" >&2
         exit 1
      fi
      tar xf "$1" 2> /tmp/tarjunk.$$
      if [ $? != 0 ]; then
         printf "" >&2
         printf "\nError: tar error
       Installation aborted.\n" >&2
         cat /tmp/tarjunk.$$ >&2
         /bin/rm -f /tmp/tarjunk.$$
         exit 1
      fi
      test -f /tmp/tarjunk.$$ && /bin/rm -f /tmp/tarjunk.$$
}
###############################################################################
#
# Function: DeTarOnly
#
# Purpose: Untar a package
#
# Notes:   
#
###############################################################################
DeTarOnly() {
      if [ ! -f "$1" ]; then
         printf "" >&2
         printf "\n\nError: Cannot locate the $3 files.
       Installation aborted.\n" >&2
         exit 1
      fi
      tar xf "$1" "$2" 2> /tmp/tarjunk.$$
      if [ $? != 0 ]; then
         printf "" >&2
         printf "\nError: tar error
       Installation aborted.\n" >&2
         cat /tmp/tarjunk.$$ >&2
         /bin/rm -f /tmp/tarjunk.$$
         exit 1
      fi
      test -f /tmp/tarjunk.$$ && /bin/rm -f /tmp/tarjunk.$$
}
###############################################################################
#
# Function: DeTarZ
#
# Purpose: Untar a compressed package
#
# Notes:   
#
###############################################################################
DeTarZ() {
      if [ ! -f "$1" ]; then
         printf "" >&2
         printf "\n\nError: Cannot locate the $2 files.
       Installation aborted.\n" >&2
         exit 1
      fi
      zcat < "$1" | tar xf - 2> /tmp/tarjunk.$$
      if [ $? != 0 ]; then
         printf "" >&2
         printf "\nError: tar error
       Installation aborted.\n" >&2
         cat /tmp/tarjunk.$$ >&2
         /bin/rm -f /tmp/tarjunk.$$
         exit 1
      fi
      test -f /tmp/tarjunk.$$ && /bin/rm -f /tmp/tarjunk.$$
}
###############################################################################
#
# Function: DeTarZOnly
#
# Purpose: Untar a compressed package
#
# Notes:   
#
###############################################################################
DeTarZOnly() {
      if [ ! -f "$1" ]; then
         printf "" >&2
         printf "\n\nError: Cannot locate the $3 files.
       Installation aborted.\n" >&2
         exit 1
      fi
      zcat < "$1" | tar xf - "$2" 2> /tmp/tarjunk.$$
      if [ $? != 0 ]; then
         printf "" >&2
         printf "\nError: tar error
       Installation aborted.\n" >&2
         cat /tmp/tarjunk.$$ >&2
         /bin/rm -f /tmp/tarjunk.$$
         exit 1
      fi
      test -f /tmp/tarjunk.$$ && /bin/rm -f /tmp/tarjunk.$$
}
###############################################################################
#
# Function: Progress
#
# Purpose: Print progress indicator
#
# Notes:   
#
###############################################################################
Progress() {
   case "$1" in
      begin)
         printf "\nInstalling $2 ."
      ;;
      dot)
         printf "."
      ;;
      end)
         printf ".\n"
      ;;
   esac
}
###############################################################################
#
# Function: TestWritable
#
# Purpose: Test if a directory is writable
#
# Notes:   
#
###############################################################################
TestWritable() {
   OLDDIR=`pwd`
   cd "$1"
   if [ ! -w junk.$$ ]; then
      touch junk.$$ > /dev/null 2>&1
      if [ $? != 0 ]; then
         cd $OLDDIR
         return 1
      else
         /bin/rm -f junk.$$
         cd $OLDDIR
         return 0
      fi
   fi
   cd $OLDDIR
   return 0
}
###############################################################################
#
# Function: GetProduct
#
# Purpose: Get which product(s) the user wants to install
#
# Notes:   Sets PROD
#
###############################################################################
GetProduct() {
   finished=""
   VAL1="No"
   VAL2="No"
   VAL3="No"
   test $ISSET1 = true && VAL1="Yes"
   test $ISSET2 = true && VAL2="Yes"
   test $ISSET3 = true && VAL3="Yes"
   test $CANDSG = 0 && VAL2="Unavailable"
   while [ "x$finished" = "x" ]; do
      Banner
      printf "
Select the product(s) you wish to install:

       Product                                                   Selected

   (1) GENESIS Structural Analysis and Optimization Software        %3s
   (2) Design Studio for Genesis Graphical Pre/Post-processor       %3s
   (3) FLEXlm server (only needed for floating licenses)            %3s
" $VAL1 $VAL2 $VAL3
      printf "
   (c) Continue
   (q) Quit the installation

   Enter a number to toggle that selection, c to continue, or q to quit
>"
      read targ
      case "$targ" in
         1) if [ x"$VAL1" = xNo ]; then
               VAL1="Yes"
            else
               VAL1="No"
            fi
            ;;
         2) if [ x"$VAL2" = xUnavailable ]; then
               printf ""
            elif [ x"$VAL2" = xNo ]; then
               VAL2="Yes"
            else
               VAL2="No"
            fi
            ;;
         3) if [ x"$VAL3" = xNo ]; then
               VAL3="Yes"
            else
               VAL3="No"
            fi
            ;;
         c|C) if [ x"$VAL1" != xYes -a x"$VAL2" != xYes -a x"$VAL3" != xYes ]; then
                 printf "\nNothing is selected for installation!
Continuing will quit the installation.  Do you want to continue"
                 if GetYesNo; then
                    PROD="QUIT"
                    finished=true
                 fi
              else
                 finished=true
              fi
            ;;
         q|Q) PROD="QUIT"
              finished=true
            ;;
         *) printf ""
            ;;
      esac
   done

   if [ x"$PROD" = "xQUIT" ]; then
      printf "\nGENESIS installation aborted.\n"
      exit 0;
   fi
   ISSET1=false
   ISSET2=false
   ISSET3=false
   test $VAL1 = Yes && ISSET1=true
   test $VAL2 = Yes && ISSET2=true
   test $VAL3 = Yes && ISSET3=true
}
###############################################################################
#
# Function: SetTarget
#
# Purpose: Target Combobox Callback
#
# Notes:   
#
###############################################################################
SetTarget() {
   TARGET="$1"
   case "$TARGET" in
      SunOS) TargetName="Sun Sparc (Solaris 10 or higher)"
         ;;
      Linux_ia64) TargetName="Generic ia64 (Linux 2.6 or higher)"
         ;;
      HP-UX) TargetName="HP PA-RISC (HP-UX 11i v1 or higher)"
         ;;
      HP-UX_ia64) TargetName="HP ia64 (HP-UX 11i v2 or higher)"
         ;;
      AIX) TargetName="IBM POWER 3+ (AIX 5.3 or higher)"
         ;;
      Linux_ix86) TargetName="Generic ix86/x86_64 (Linux 2.6 or higher)"
         ;;
      *) TargetName="Unknown"
         ;;
   esac
   case "$TARGET" in
      SunOS|HP-UX|Linux_ix86|AIX) 
            CANDSG=1
      ;;
      *)
            ISSET2=false
            CANDSG=0
      ;;
   esac
}
###############################################################################
#
# Function: SelectPlatform
#
# Purpose: prompt the user to select a computer platform
#
# Notes:   Sets TARGET to the plaform name
#          Can exit
#
###############################################################################
SelectPlatform() {
   TARGET=
   while [ "x$TARGET" = "x" ]; do
      Banner
      printf "%s" '
Select the target platform type:

   (1) Generic ix86/x86_64  (Linux 2.6 or higher)
   (2) Generic ia64         (Linux 2.6 or higher)
   (3) IBM POWER 3+         (AIX 5.3 or higher)
   (4) Sun Sparc            (Solaris 10 or higher)
   (5) HP ia64              (HP-UX 11i v2 or higher)
   (6) HP PA-RISC           (HP-UX 11i v1 or higher)

   (q) Quit the installation
>'
      read targ
      case "$targ" in
         1) SetTarget Linux_ix86
            ;;
         2) SetTarget Linux_ia64
            ;;
         3) SetTarget AIX
            ;;
         4) SetTarget SunOS
            ;;
         5) SetTarget HP-UX_ia64
            ;;
         6) SetTarget HP-UX
            ;;
         q|Q) TARGET="QUIT"
            ;;
         *) printf ""
            ;;
      esac
   done

   if [ $TARGET = "QUIT" ]; then
      printf "\nGENESIS installation aborted.\n"
      exit 0;
   fi
}
###############################################################################
#
# Function: VerifyDir
#
# Purpose: check that the users selected directory is OK
#
# Notes:   Sets TODIR to the directory
#          Can exit on errors
#
###############################################################################
VerifyDir() {
   if [ $ISSET1 = true ]; then
      if [ -f "$targ/vrand/${GENDIR}/$TARGET/genesis.x" ]; then
         printf ""
         printf "
GENESIS ${GENVER} is already installed in this directory.
Do you want to continue (and overwrite the existing installation!)\n"
         if GetYesNo; then
            OLDDIR=`pwd`
            cd "$targ"
            TODIR=`pwd`
            cd $OLDDIR
         else
            TODIR=
            return
         fi
      elif [ -f "$targ/vrand/${GENDIR}" ]; then
         /bin/mv -f "$targ/vrand/${GENDIR}" "$targ/vrand/${GENDIR}_saved_file"
         if [ $? != 0 ]; then
            printf ""
            printf "\nThis directory contains a file named vrand/${GENDIR} that could not be renamed!
Select a different directory.\n"
            PressReturn
            TODIR=
            return
         else
            OLDDIR=`pwd`
            cd "$targ"
            TODIR=`pwd`
            cd $OLDDIR
         fi
      else
         OLDDIR=`pwd`
         cd $targ
         TODIR=`pwd`
         cd $OLDDIR
      fi
   fi
   if [ $ISSET2 = true ]; then
      if [ -f "$TODIR/vrand/${GENDIR}/$TARGET/libdsg.so" -o \
           -f "$TODIR/vrand/${GENDIR}/$TARGET/libdsg.sl" ]; then
         printf ""
         printf "
Design Studio for Genesis ${GENVER} is already installed in this directory.
Do you want to continue (and overwrite the existing installation!)\n"
         if GetYesNo; then
            OLDDIR=`pwd`
            cd "$targ"
            TODIR=`pwd`
            cd $OLDDIR
         else
            TODIR=
            return
         fi
      elif [ -f "$targ/vrand/${GENDIR}" ]; then
         /bin/mv -f "$targ/vrand/${GENDIR}" "$targ/vrand/${GENDIR}_saved_file"
         if [ $? != 0 ]; then
            printf ""
            printf "\nThis directory contains a file named vrand/${GENDIR} that could not be renamed!
Select a different directory.\n"
            PressReturn
            TODIR=
            return
         else
            OLDDIR=`pwd`
            cd "$targ"
            TODIR=`pwd`
            cd $OLDDIR
         fi
      else
         OLDDIR=`pwd`
         cd $targ
         TODIR=`pwd`
         cd $OLDDIR
      fi
   fi
   if [ $ISSET3 = true ]; then
      OLDDIR=`pwd`
      cd $targ
      TODIR=`pwd`
      cd $OLDDIR
   fi
}
###############################################################################
#
# Function: SelectDir
#
# Purpose: prompt the user to select a directory
#
# Notes:   Sets TODIR to the directory
#          Can exit on errors
#
###############################################################################
SelectDir() {
   TODIR=""
   while [ "x$TODIR" = "x" ]; do
      Banner
      printf "
Enter the full path of the directory in which to install
(e.g., /opt or /usr/local)
or 'quit' to quit the installation
>"
      read targ
      case "$targ" in
         */vrand|*/vrand/) targ=`dirname $targ`
         ;;
      esac
      if [ -z "$targ" ]; then
         printf "\n"
      elif [ "$targ" = "quit" -o "$targ" = 'q' ]; then
         printf "\n%s\n" 'GENESIS installation aborted.'
         exit 0
      elif [ -d "$targ/vrand" ]; then
         if TestWritable "$targ/vrand"; then
            VerifyDir
         else
            printf ""
            printf "\nYou do not have write-permission for $targ/vrand \n"
            PressReturn
         fi
      elif [ -d "$targ" ]; then
         if TestWritable "$targ"; then
            VerifyDir
         else
            printf ""
            printf "\nYou do not have write-permission for $targ \n"
            PressReturn
         fi
      else
         printf "
Installation directory $targ does not exist.
Do you want to create it

*** NOTE ***
All files will be installed in a directory named vrand
(created automatically) in the installation directory.
You probably want to answer 'No' and enter an existing directory
as the installation directory.
"
         if GetYesNo; then
            printf "\nCreating directory: $targ\n"
            mkdir -p "$targ"
            if [ $? != 0 ]; then
               printf ""
               printf "\nError: could not create directory\n"
               PressReturn
            else
               OLDDIR=`pwd`
               cd "$targ"
               TODIR=`pwd`
               cd "$OLDDIR"
            fi
         fi
      fi
   done
}
###############################################################################
#
# Function: GetLenvec
#
# Purpose: Get the value for the default Lenvec
#
# Notes:  
#
###############################################################################
GetLenvec() {
   if [ $ISSET1 = true ]; then
      PROMPT="Enter the default amount of memory GENESIS should use (in Mb)" 
      SCRIPT="genesis"
   else
      return
   fi
   LENVEC=""
   while [ "x$LENVEC" = "x" ]; do
      Banner
      printf "
$PROMPT
(E.g., 128 or 128Mb) or 'quit' to abort
>"
      read lenv
      if [ -z "$lenv" ]; then
         printf "\n"
      elif [ "$lenv" = "quit" -o "$lenv" = 'q' ]; then
         printf "\n%s\n" 'GENESIS installation aborted.'
         exit 0
      else
         units=`expr $lenv : '[0-9]*\([a-zA-Z]*\)'`
         mem=`expr $lenv : '\([0-9]*\)'`
         if [ -z "$mem" ];then
            printf "\n"
         else
            case "$units" in
               GB|gb|Gb) bytes=`expr $mem \* 1000000000`
                  ;;
               MB|mb|Mb) bytes=`expr $mem \* 1000000`
                  ;;
               KB|kb|Kb) bytes=`expr $mem \* 1000`
                  ;;
               *) bytes=`expr $mem \* 1000000`
                  ;;
            esac
            if [ $bytes -lt 16000000 ]; then
               printf ""
               printf "\n%s\n" 'GENESIS requires at least 16MB to run!'
               PressReturn
            elif [ $bytes -lt 32000000 ]; then
               LENVEC=`expr \( $bytes - 8000000 \) / 4`
            elif [ $bytes -lt 64000000 ]; then
               LENVEC=`expr \( $bytes - 16000000 \) / 4`
            elif [ $bytes -lt 96000000 ]; then
               LENVEC=`expr \( $bytes - 20000000 \) / 4`
            else
               LENVEC=`expr \( $bytes - 24000000 \) / 4`
            fi
         fi
      fi
   done
   memused=`expr $LENVEC \* 4 + 24000000`
   printf ""
   printf "\nConfiguring the default LENVEC to $LENVEC \n"
   printf "\nNOTE: With this configuration, GENESIS will use
approximately $memused bytes of memory.\n"
   printf "\nThis can be changed by setting the environment variable
\"GENESIS_LENVEC\" to the desired value in the $SCRIPT script.\n"
   PressReturn
}
###############################################################################
#
# Function: Confirm
#
# Purpose: Confirm the user selections for platform and install dir
#
# Notes:  
#
###############################################################################
Confirm() {
   OK=""
   while [ "x$OK" = "x" ]; do
      ProdName=
      if [ $ISSET1 = true ]; then
         ProdName="$ProdName
          GENESIS Structural Analysis and Optimization Software"
      fi
      if [ $ISSET2 = true ]; then
         ProdName="$ProdName
          Design Studio for Genesis Graphical Pre/Post-processor"
      fi
      if [ $ISSET3 = true ]; then
         ProdName="$ProdName
          FLEXlm license server"
      fi
      Banner
      printf "\n
   (1) Product(s) $ProdName
   (2) Target Platform          = $TargetName
   (3) Install into             = $TODIR"
      if [ $ISSET1 = true ]; then
         printf "
   (4) LENVEC                   = $LENVEC"
      fi
      printf "

   (c) Continue
   (q) Quit

   Enter a number to make a change, c to continue, or q to quit:
>"
      read okans
      case "$okans" in
         1) GetProduct
            ;;
         2) SelectPlatform
            ;;
         3) SelectDir
            ;;
         4) if [ $ISSET1 = true ]; then
               GetLenvec
            else
               printf ""
            fi
            ;;
         c|C) OK="OK"
            ;;
         q|Q) OK="QUIT"
            ;;
         *) printf ""
            ;;
      esac
   done
   if [ $OK = "QUIT" ]; then
      printf "\n%s\n" 'GENESIS installation aborted.'
      exit 0;
   fi
}
###############################################################################
#
# Function: AgreeYesNo
#
# Purpose: prompt the user to enter yes or no
#
# Notes:   Sets ANS to "YES" or "NO"
#
###############################################################################
AgreeYesNo() {
   ANS=""
   while [ "x$ANS" = "x" ]; do
      printf "
   (y) Yes, I agree
   (n) No, quit the installation
?"
      read ans
      case "$ans" in
         y|yes|Y|YES) return 0
            ;;
         n|no|N|NO) return 1
            ;;
         *) printf ""
            ;;
      esac
   done
}
###############################################################################
#
#  Begin main script code
#
###############################################################################
if [ ! -f "$LICFILE" ]; then
   printf ""
   printf "\nError: Cannot locate the installation files.
       Installation aborted.\n"
   exit 1
fi
more "$LICFILE"
printf "\nDo you agree to the license terms"
AgreeYesNo || exit 0
ISSET1=true
ISSET2=true
ISSET3=true
TARGET=`uname`
case $TARGET in
   AIX*)  TARGET="AIX" ;;
   Linux) TARGET="Linux_ix86"
      case `uname -m` in
         ia64*) TARGET="Linux_ia64" ;;
      esac
   ;;
   HP-UX)
      case `model` in
         ia64*) TARGET="HP-UX_ia64" ;;
      esac
   ;;
   SunOS) TARGET="SunOS_ix86"
      case `uname -p` in
         sparc*) TARGET="SunOS" ;;
      esac
   ;;
esac
SetTarget $TARGET
Banner
if [ x"$TargetName" = xUnknown ]; then
   SelectPlatform
else
   printf "
The local system appears to be $TargetName.
Is this the correct target platform type"
   GetYesNo || SelectPlatform
fi
GetProduct
SelectDir
GetLenvec
Confirm
   INSTALLLOG="$TODIR/vrand/genesis_install.log"
   test -f "$INSTALLLOG" && mv "$INSTALLLOG" "${INSTALLLOG}.old"
#
#  install the FLEXlm lmutil program
#
   cd "$TODIR"
#
   DeTarZOnly "$FLEXLM" "vrand/flexlm/$TARGET/lmutil" "flexlm"
   DeTarZOnly "$FLEXLM" "vrand/flexlm/doc" "flexlm"
#
   if [ ! -d vrand/bin ]; then
      mkdir -p vrand/bin
      chmod a+rx vrand/bin
   fi
   sed -e "s?\"ZZZvrand_pathZZZ\"?\"$TODIR/vrand\"?" \
       "$LMU" > vrand/bin/lmutil
#
   chmod a+rx vrand/bin/lmutil
   test -f vrand/bin/lmhostid && rm vrand/bin/lmhostid
   ln vrand/bin/lmutil vrand/bin/lmhostid

   if [ $ISSET1 = true ]; then
      SOURCE32=""
      case "$TARGET" in
         SunOS)     SOURCE="$GENSUN" ;;
         HP-UX)     SOURCE="$GENHP" ;;
         HP-UX_ia64)     SOURCE="$GENHPI" ;;
         AIX)       SOURCE="$GENIBM" ;;
         Linux_ix86)SOURCE="$GENLNX"
                    SOURCE32="$GENLNX32"
         ;;
         Linux_ia64)SOURCE="$GENATX" ;;
         *) printf "\n\nProgrammer error in install script -- exiting\n" >&2
            exit 1
            ;;
      esac

      Progress begin GENESIS

      DeTarZ "$GENMI" "GENESIS"
      DeTarZ "$SOURCE" "GENESIS"
      test x"$SOURCE32" != x && DeTarZ "$SOURCE32" "GENESIS"

      Progress dot
#
#  make the genesis script
#
      sed -e "s?\"ZZZvrand_pathZZZ\"?\"$TODIR/vrand\"?" \
          -e "s?\"ZZZgenesis_dirZZZ\"?\"${GENDIR}\"?" \
          -e "s?\"ZZZgenesis_descZZZ\"?\"${GENVER}\"?" \
          -e "s?\"ZZZgenesis_lenvecZZZ\"?\"$LENVEC\"?" \
          "$RUNG" > vrand/bin/genesis-${GENVER}
#
      Progress dot

      chmod a+rx vrand/bin/genesis-${GENVER}
      test -f vrand/bin/genesis && rm vrand/bin/genesis
      ln -s genesis-${GENVER} vrand/bin/genesis
      chmod a+rx vrand/bin/genesis
      test -f vrand/bin/rung && rm vrand/bin/rung
      #ln -s genesis-${GENVER} vrand/bin/rung
      #chmod a+rx vrand/bin/rung
#
      Progress dot

      if [ ! -d vrand/licenses ]; then
         mkdir vrand/licenses
         chmod a+rx vrand/licenses
      fi

      if [ ! -d vrand/etc ]; then
         mkdir vrand/etc
         chmod a+rx vrand/etc
      fi

      Progress dot
#
      DeTarZOnly "$GENDNS" "vrand/${GENDIR}/$TARGET" "dns2dat"
      DeTarZOnly "$GENDNS" "vrand/unsupported" "dns2dat"
#
#  make the dns2dat script (setting the path to genesis
#
      sed -e "s?\"ZZZvrand_pathZZZ\"?\"$TODIR/vrand\"?" \
          -e "s?\"ZZZgenesis_dirZZZ\"?\"${GENDIR}\"?" \
          "$DNS2DAT" > vrand/bin/dns2dat-${GENVER}
#
      chmod a+rx vrand/bin/dns2dat-${GENVER}
      test -f vrand/bin/dns2dat && rm vrand/bin/dns2dat
      ln -s dns2dat-${GENVER} vrand/bin/dns2dat
      chmod a+rx vrand/bin/dns2dat
#
      Progress end
#
   fi
###############################################################################
#
# install Design Studio (if desired)
#
###############################################################################
   if [ $ISSET2 = true ]; then
      case "$TARGET" in
         SunOS)     SOURCE="$DSGSUN" ;;
         HP-UX)     SOURCE="$DSGHP"  ;;
         Linux_ix86)SOURCE="$DSGLNX" ;;
         AIX)       SOURCE="$DSGIBM" ;;
         *) printf "\n\nProgrammer error in install script -- exiting\n" >&2
            exit 1
            ;;
      esac
      Progress begin "Design Studio"

      DeTarZ "$DSGMI" "Design Studio"
      DeTarZ "$SOURCE" "Design Studio"

      Progress dot

      sed -e "s?\"ZZZvrand_pathZZZ\"?\"$TODIR/vrand\"?" \
          -e "s?\"ZZZgenesis_dirZZZ\"?\"${GENDIR}\"?" \
          "$DSG" > vrand/bin/dsg-${GENVER}
#
      Progress dot

      chmod a+rx vrand/bin/dsg-${GENVER}
      test -f vrand/bin/dsg && rm vrand/bin/dsg
      ln -s dsg-${GENVER} vrand/bin/dsg
      chmod a+rx vrand/bin/dsg
#
      Progress dot

      if [ ! -d vrand/licenses ]; then
         mkdir vrand/licenses
         chmod a+rx vrand/licenses
      fi

      Progress end
   fi
###############################################################################
#
# install FLEXlm (if desired)
#
###############################################################################
   if [ $ISSET3 = true ]; then

      Progress begin "FLEXlm"
#
      DeTarZOnly "$FLEXLM" "vrand/flexlm/$TARGET" "flexlm"
      DeTarZOnly "$FLEXLM" "vrand/flexlm/doc" "flexlm"

      Progress dot
#
      sed -e "s?\"ZZZvrand_pathZZZ\"?\"$TODIR/vrand\"?" \
          "$LMG" > vrand/bin/lmgrd
#
      chmod a+rx vrand/bin/lmgrd

      Progress dot
#
      test -f vrand/bin/lmcksum   && rm vrand/bin/lmcksum
      test -f vrand/bin/lmdiag    && rm vrand/bin/lmdiag
      test -f vrand/bin/lmdown    && rm vrand/bin/lmdown
      test -f vrand/bin/lminstall && rm vrand/bin/lminstall
      test -f vrand/bin/lmremove  && rm vrand/bin/lmremove
      test -f vrand/bin/lmreread  && rm vrand/bin/lmreread
      test -f vrand/bin/lmnewlog  && rm vrand/bin/lmnewlog
      test -f vrand/bin/lmswitchr && rm vrand/bin/lmswitchr
      test -f vrand/bin/lmstat    && rm vrand/bin/lmstat
      test -f vrand/bin/lmver     && rm vrand/bin/lmver
      ln vrand/bin/lmutil vrand/bin/lmcksum
      ln vrand/bin/lmutil vrand/bin/lmdiag
      ln vrand/bin/lmutil vrand/bin/lmdown
      ln vrand/bin/lmutil vrand/bin/lminstall
      ln vrand/bin/lmutil vrand/bin/lmremove
      ln vrand/bin/lmutil vrand/bin/lmreread
      ln vrand/bin/lmutil vrand/bin/lmnewlog
      ln vrand/bin/lmutil vrand/bin/lmswitchr
      ln vrand/bin/lmutil vrand/bin/lmstat
      ln vrand/bin/lmutil vrand/bin/lmver

      Progress end
   fi
###############################################################################
#
# install the online manuals (if desired)
#
###############################################################################
   Progress begin manuals

   if [ $ISSET1 = true -o $ISSET2 = true ]; then

      if [ ! -d "$MANDIR" ]; then
         printf "\n\nError: Cannot locate the manual files.
       Manual installation aborted.\n" >&2
      else

         mkdir -p "$TODIR/vrand/${GENDIR}/manuals"
         chmod a+rx "$TODIR/vrand/${GENDIR}/manuals"
for file in "$MANDIR"/*
do
   if [ -f "$file" ]; then
      case "$file" in
         */quickref.pdf*|*/QUICKREF.PDF*)
            cp -p "$file" "$TODIR/vrand/${GENDIR}/manuals/quickref.pdf"
            ;;
         */dsgfeat.pdf*|*/DSGFEAT.PDF*)
            cp -p "$file" "$TODIR/vrand/${GENDIR}/manuals/dsgfeatures.pdf"
            ;;
         */volume1.pdf*|*/VOLUME1.PDF*)
            cp -p "$file" "$TODIR/vrand/${GENDIR}/manuals/volume1.pdf"
            ;;
         */volume2.pdf*|*/VOLUME2.PDF*)
            cp -p "$file" "$TODIR/vrand/${GENDIR}/manuals/volume2.pdf"
            ;;
         */volume3.pdf*|*/VOLUME3.PDF*)
            cp -p "$file" "$TODIR/vrand/${GENDIR}/manuals/volume3.pdf"
            ;;
         */volume4.pdf*|*/VOLUME4.PDF*)
            cp -p "$file" "$TODIR/vrand/${GENDIR}/manuals/volume4.pdf"
            ;;
         */newfeat.pdf*|*/NEWFEAT.PDF*)
            cp -p "$file" "$TODIR/vrand/${GENDIR}/manuals/newfeatures.pdf"
            ;;
         */dsgexamp.pdf*|*/DSGEXAMP.PDF*)
            cp -p "$file" "$TODIR/vrand/${GENDIR}/manuals/dsgexamples.pdf"
            ;;
         */dsghowto.pdf*|*/DSGHOWTO.PDF*)
            cp -p "$file" "$TODIR/vrand/${GENDIR}/manuals/dsghowto.pdf"
            ;;
      esac
   fi
done
         if [ $? != 0 ]; then
            printf "\nError: cp error
       Manual installation aborted.\n" >&2
         fi
      fi
   fi

   Progress end
###############################################################################
#
# print success messages
#
###############################################################################
if [ $ISSET3 = true ]; then
   Network="        Network: Yes"
else
   Network="        Network: No"
fi
ReqDate="   Request Date: `date +%d-%b-%Y`"
if [ $ISSET1 = true ]; then
   Product="        Product: GENESIS ${GENVER}"
fi
if [ $ISSET2 = true ]; then
   Product="$Product
        Product: Design Studio for Genesis ${GENVER}"
fi
case `uname` in
   AIX*)
SYSTEMTYPE="`uname -s` `uname -v`.`uname -r`"
   ;; 
   HP-UX)
SYSTEMTYPE="`/usr/bin/uname -sr` `model` `/usr/bin/getconf _SC_CPU_VERSION`"
   ;; 
   SunOS)
SYSTEMTYPE="`/usr/bin/uname -sri`"
   ;; 
   *)
SYSTEMTYPE="`uname -srm`"
   ;; 
esac
HOSTNAME=`hostname`
HOSTID=`"$TODIR/vrand/bin/lmhostid" -n`
if [ -f "$TODIR/vrand/license_request_form.txt" ]; then
mv "$TODIR/vrand/license_request_form.txt" "$TODIR/vrand/license_request_form.txt.old"
fi
cat <<EOF3 > "$TODIR/vrand/license_request_form.txt"
This system information is used to create the GENESIS authorization file.
If you have purchased/leased a GENESIS license, 
or you have arranged to receive a no-cost evaluation license,
fill in the following information and send this file to VR&D or
to your distributor:

(VR&D email: license@vrand.com)

Client Information
   Organization: 
 Contact Person: 
        Address: 
               : 
               : 
          Email: 
          Phone: 
            Fax: 
$ReqDate
   License Type: (mark one) Commercial  [ ]
                            Educational [ ]
                            Evaluation  [ ]
$Network

System Information
    System Type: $SYSTEMTYPE
       Hostname: $HOSTNAME
       LMHostid: $HOSTID

Product Information
$Product
EOF3
   FINISHMSG=""
   if [ $ISSET1 = true ]; then
      FINISHMSG="$FINISHMSG
GENESIS was installed in
$TODIR/vrand

Copy the script $TODIR/vrand/bin/genesis
to a place in the users' path or modify each users' path to include 
$TODIR/vrand/bin

Run GENESIS directly by executing the genesis script
(E.g., genesis mydata.dat) 

GENESIS manuals were installed in
$TODIR/vrand/${GENDIR}/manuals "
   fi
   if [ $ISSET2 = true ]; then
      FINISHMSG="$FINISHMSG

Design Studio was installed in
$TODIR/vrand

Copy the script $TODIR/vrand/bin/dsg
to a place in the users' path or modify each users' path to include 
$TODIR/vrand/bin

Launch Design Studio by executing the dsg script"

   fi
   if [ $ISSET3 = true ]; then
      FINISHMSG="$FINISHMSG

The FLEXlm license server for VR&D Products was installed in
$TODIR/vrand

Start the license server by running the script
$TODIR/vrand/bin/lmgrd

You can read the FLEXlm End-User Documentation by viewing
$TODIR/vrand/flexlm/doc/enduser.pdf"
   fi
   FINISHMSG="$FINISHMSG

Use the file $TODIR/vrand/license_request_form.txt
to request a GENESIS authorization file from Vanderplaats R&D or your
distributor. When you receive the license file, save it as genesis.lic in
$TODIR/vrand/licenses

"

   printf "$FINISHMSG \n\n"

   echo "$FINISHMSG" > "$INSTALLLOG"
   printf "A log of the installation is saved in 
$INSTALLLOG \n" >&2

