#!/bin/sh
#
##################################################
# dsg version 11.0
# script for Design Studio for GENESIS
##################################################
#
#####################################################
#####            Copyright 1998-2009            #####
##### Vanderplaats Research & Development, Inc. #####
#####            All rights reserved.           #####
#####################################################
#
# VRAND_PATH and GENESIS_DIR should have been set by the GENESIS
# installation script
#
#  VRAND_PATH     (the path to the installation directory + /vrand)
#  GENESIS_DIR    (the GENESIS directory under vrand)
#
VRAND_PATH="ZZZvrand_pathZZZ"
#
GENESIS_DIR="ZZZgenesis_dirZZZ"
#
# GRAPHICS_INDEX can be set to the index of the GraphicsConfiguration to use
# (this should only be set if the default GraphicsConfiguration is not
#  adequate)
# this can be changed on the command line with the -g index option
#
GRAPHICS_INDEX=""
#
#  JAVA can be set in the environment to specify the full path
#  to the java runtime executable.  If it is not set, this script
#  will search for java in some standard places.  If a suitable 
#  java cannot be found, then it will ask the user to type the
#  path to java.
#
#
#                NOTHING AFTER THIS LINE SHOULD BE CHANGED!
##############################################################################
#
if [ ! -d "$VRAND_PATH" ]; then
   what=`basename "$0"`
   where=`dirname "$0"`
   here=`pwd`
   test x"$where" = x. && where="$here"
   case $where in
      /*) : ;;
      *) where="$here/$where" ;;
   esac
   while [ -L "$where/$what" ]; do
      ls=`/bin/ls -l "$where/$what"`
      cmd=`expr "$ls" : ".*-> \(.*\)"`
      what=`basename "$cmd"`
      newwhere=`dirname "$cmd"`
      test x"$newwhere" = x. && newwhere="$where"
      case $newwhere in
         /*) : ;;
         *) newwhere="$where/$newwhere" ;;
      esac
      where="$newwhere"
   done
   case $where in
      */vrand/bin) 
         VRAND_PATH=`expr "$where" : "\(.*\)/bin"`
      ;;
      *) printf "Error: Design Studio was not properly installed!
       Edit the dsg script and set the variable \"VRAND_PATH\"
       to the full path to the vrand directory.
" >&2
         exit 1
      ;;
   esac
fi
#
export VRAND_PATH
#
if [ -f $HOME/.dsgrc ]; then
   . $HOME/.dsgrc
   test "x$JAVA" = x && JAVA="$PREVIOUS_JAVA"
fi
#
OSTYPE=`uname`
case $OSTYPE in
   IRIX*) OSTYPE="IRIX"
          JavaURL="http://www.sgi.com/products/evaluation/"
   ;;
   Linux) OSTYPE="Linux_ix86"
      case `uname -m` in
         ia64*) OSTYPE="Linux_ia64" ;;
      esac
          JavaURL="http://java.sun.com/j2se/"
      LD_LIBRARY_PATH="$VRAND_PATH/$GENESIS_DIR/$OSTYPE:$LD_LIBRARY_PATH"
      export LD_LIBRARY_PATH
   ;;
   HP-UX)
      case `model` in
         ia64*) OSTYPE="HP-UX_ia64" ;;
      esac
          JavaURL="http://www.hp.com/products1/unix/java/"
      test "x$GRAPHICS_INDEX" = x && GRAPHICS_INDEX=1
      SHLIB_PATH="$VRAND_PATH/$GENESIS_DIR/$OSTYPE:$SHLIB_PATH"
      export SHLIB_PATH
   ;;
   AIX)   JavaURL="http://www-128.ibm.com/developerworks/java/jdk/aix/service.html"
      LIBPATH="$VRAND_PATH/$GENESIS_DIR/$OSTYPE:$LIBPATH"
      export LIBPATH
   ;;
   SunOS) JavaURL="http://java.sun.com/j2se/"
      LD_LIBRARY_PATH="$VRAND_PATH/$GENESIS_DIR/$OSTYPE:$LD_LIBRARY_PATH"
      export LD_LIBRARY_PATH
   ;;
   Darwin) OSTYPE="Darwin_ix86"
      case `arch` in
         ppc*) OSTYPE="Darwin_ppc" ;;
      esac
          JavaURL="http://www.apple.com/java"
   ;;
esac
#
args=
test "x$GRAPHICS_INDEX" != x && args="\"-g$GRAPHICS_INDEX\""
while [ $# != 0 ]; do
   case $1 in
      -G|-g) if [ $# -gt 1 ]; then
                args="$args \"-g$2\""
                shift;
             fi
          ;;
      -G*|-g*) opt=`expr "$1" : "-.\(.*\)"`
             args="$args \"-g$opt\""
          ;;
      -view*) args="$args -viewer"
          ;;
      -J)    if [ $# -gt 1 ]; then
                JAVAOPTIONS="$JAVAOPTIONS $2"
                shift;
             fi
          ;;
      -J*) opt=`expr "$1" : "-J\(.*\)"`
           JAVAOPTIONS="$JAVAOPTIONS $opt"
          ;;
      -64) JAVAOPTIONS="$JAVAOPTIONS -d64"
          ;;
      *) args="$args \"$1\""
         ;;
   esac
   shift
done
#
GetJavaVersion() {
   jvers=0.0.0
   if [ -x "$1" ]; then
      "$1" -version > /tmp/java_version 2>&1
      temp=`cat /tmp/java_version`
      rm -f /tmp/java_version
      set -- $temp
      test x"$1" = xjava && jvers=`expr "$3" : ".*\([0-9]\.[0-9]\.[0-9]\)"`
   fi
}
#
if [ "x$JAVA" = x ]; then
   for targ in /usr/java*/jre/bin/java /opt/java*/jre/bin/java /opt/jre*/bin/java /opt/jdk*/jre/bin/java /usr/bin/java; do
      if [ "x$JAVA" = x -a -f "$targ" ]; then
         GetJavaVersion "$targ"
         case $jvers in
            0*|1.0*|1.1*|1.2*|1.3*)
            :
            ;;
            *) JAVA="$targ"
            ;;
         esac
      fi
   done
fi
while [ "x$JAVA" = x ]; do
   printf "
Design Studio for Genesis requires a Java Runtime Environment (JRE) to function.
NOTE: The JRE must be version 1.4 or higher.
      If you do not have JRE 1.4 or higher, contact your computer system
      vendor, or check the following URL:
      $JavaURL

Please type in the full path of the java executable,
e.g., /usr/local/java1.4/bin/java (enter a blank line to abort):
"
   read targ
   if [ -z "$targ" ]; then
      printf "Aborting...\n"
      exit 0
   elif [ -d "$targ" ]; then
      printf ""
      printf "\n$targ is a directory. Please specify an executable.\n"
   elif [ ! -x "$targ" ]; then
      printf ""
      printf "\n$targ is not executable.\n"
   else
      GetJavaVersion "$targ"
      printf "\n$targ appears to be version $jvers.\n"
      case $jvers in
         0*|1.0*|1.1*|1.2*|1.3*) 
         printf ""
         printf "\nDesign Studio requires a later version.\n"
         ;;
         *)
         JAVA="$targ"
         printf "PREVIOUS_JAVA=\"$targ\"\n" >> $HOME/.dsgrc
         ;;
      esac
      printf "\n"
   fi
done
#
eval set -- $args
CLASSPATH="$VRAND_PATH/$GENESIS_DIR/jar/dsg.jar:$VRAND_PATH/$GENESIS_DIR/jar/jh.jar:$VRAND_PATH/$GENESIS_DIR/jar/dsg-help.jar"
export CLASSPATH
exec "$JAVA" $JAVAOPTIONS "-Djava.library.path=$VRAND_PATH/$GENESIS_DIR/$OSTYPE" "-Dvrand.path=$VRAND_PATH" vrand.DesignStudio "$@"
