#!/bin/sh
#
##################################################
# genesis version 11.0
# script file to run Genesis
##################################################
#
#####################################################
#####            Copyright 1998-2009            #####
##### Vanderplaats Research & Development, Inc. #####
#####            All rights reserved.           #####
#####################################################
#
##############################################################################
#  Start of user modifiable part -- Set these variables accordingly
##############################################################################
#
# These variables set defaults for how the genesis script works
# Change these according to site preferences
#
# These can be changed at run-time with command-line switches (shown in [])
#
#   MakeDiff
#       [-d]    1 = make the DIF file 
#       [-nod]  0 = do not make the DIF file
#   ShowErrors
#       [-e]    1 = echo any error messages in the output file to the screen
#       [-noe]  0 = do not echo error messages to the screen
#   Verbose
#       [-v]    1 = print verbose messages about the run
#       [-nov]  0 = do not print anything
#   SaveOldOut
#       [-old=n] n = save old out versions as *.out.0 *.out.1 ... *.out.{n-1}
#       [-noold] 0 = do not save old out file
#
MakeDiff=0
ShowErrors=1
Verbose=0
SaveOldOut=1
#
#   ACROREAD  name of pdf viewer executable 
#       
test "x$ACROREAD" = x && ACROREAD=acroread
#
# The remaining variables may be set and exported by scripts that 
# call this script.  If any are not set (e.g., if this script is executed
# directly), then they are set to default values here.
#
# These defaults may be changed as necessary.
#
#  These may be changed per site preferences
#
#   DAT        (data input file extension)
#   OUT        (output file extension)
#   LOG        (log file extension)
#   DIF        (output to old_output diff file extension)
#   GENESIS_THREADS  (default number of threads for SMP parallelism)
#
test "x$DAT" = x && DAT=dat
test "x$OUT" = x && OUT=out
test "x$LOG" = x && LOG=log
test "x$DIF" = x && DIF=dif
test "x$GENESIS_THREADS" = x && GENESIS_THREADS=1
#
#
# VRAND_PATH, gendir, gendesc, and GENESIS_LENVEC
# should have been set by the Genesis installation script
#
# set values for:
#  VRAND_PATH     (the path to the installation directory + /vrand)
#  gendir         (the Genesis directory under vrand)
#  gendesc        (the Genesis version description)
#  GENESIS_LENVEC (the default amount of memory (in words) Genesis should use)
#
VRAND_PATH="ZZZvrand_pathZZZ"
#
gendir="ZZZgenesis_dirZZZ"
#
gendesc="ZZZgenesis_descZZZ"
#
test "x$GENESIS_LENVEC" = x && GENESIS_LENVEC="ZZZgenesis_lenvecZZZ"
#
##############################################################################
#  End of user modifiable part -- NOTHING BELOW THIS LINE SHOULD BE CHANGED!
##############################################################################
#
Usage() {
   printf "`basename $0` [options] input_file [input_file ...]
 or
`basename $0` -vol1|-vol2|-vol3|-vol4
        Run Genesis $gendesc using the named input_files.
        If input_file has no extension, a default of '.$DAT' is used.
        The output file has '.$OUT' as the extension.
        The options available are:
             -lenvec=n       add executive control LENVEC=n
             -threads=n      add executive control THREADS=n
             -iobuff=n,mK    add executive control IOBUFF=n,mK
             -diag=d1,d2,dn  add executive control DIAG=d1,d2,dn
             -restart=n,m    add executive control RESTART=n,m
             -dirall=path    add executive control DIRALL=path
             -check          add executive control CHECK
             -analysis       add executive control ANALYSIS
             -sensitivity    add executive control SENSITIVITY
             -p pname   set the project name to pname
             -d (-nod)  make (do not make) a diff file if an old output file
                        exists
             -e (-noe)  echo (do not echo) any error messages in the output
                        file to the screen
             -v (-nov)  print (do not print) verbose messages about the run
             -old[=n]   save n old output versions
" >&2
if [ -x "$genesis_x_32" ]; then
   printf "             -32        use the 32-bit genesis executable
             -64        use the 64-bit genesis executable
" >&2
fi
   printf "             -vol1 -vol2 -vol3 -vol4
                        view a user manual pdf file
                           Volume 1 = Analysis Reference
                           Volume 2 = Design Reference
                           Volume 3 = Analysis Examples
                           Volume 4 = Design Examples
" >&2
   omsg="        The default options are: -lenvec=$original_lenvec -threads=$original_threads"
   if [ x"$MakeDiff" = x1 ]; then omsg="$omsg -d"; else omsg="$omsg -nod"; fi
   if [ x"$ShowErrors" = x1 ]; then omsg="$omsg -e"; else omsg="$omsg -noe"; fi
   if [ x"$Verbose" = x1 ]; then omsg="$omsg -v"; else omsg="$omsg -nov"; fi
   omsg="$omsg -old=$SaveOldOut"
   printf "$omsg\n\n" >&2
}
#
rotate() {
   base="$1"
   count="$2"
   test x"$base" != x && test -f "$base" || return
   rev=`expr "$count" : "\([0-9]*\)"`
   test x$rev = x && return
   rev=`expr $rev - 1`
   test $rev -lt 0 && return
   while [ $rev -gt 0 ]; do
      prev=`expr $rev - 1`
      if [ -f "$base.$prev" ]; then
         mv "$base.$prev" "$base.$rev"
      fi
      rev=$prev
   done
   mv "$base" "$base.0"
}
printenvvar() {
   eval x=\${$1}
   if [ x"$x" != x ]; then
      cat <<EOF0 >> "$2"
$1=$x
EOF0
   fi
}
#
original_lenvec=$GENESIS_LENVEC
#
original_threads=$GENESIS_THREADS
#       
test "x$HOSTNAME" = x && HOSTNAME=`hostname`
#
ostype=`uname`
case $ostype in
   AIX*)  ostype="AIX" 
          systype="`uname -sv`.`uname -r`" ;;
   IRIX*) ostype="IRIX" 
          systype=`uname -sR` ;;
   UNICOS*) ostype="UNICOS" 
          systype=`uname -sr` ;;
   Linux) ostype="Linux_ix86"
          systype=`uname -srm`
      case `uname -m` in
         ia64*) ostype="Linux_ia64" ;;
      esac
   ;;
   HP-UX) systype="`uname -sr` `model`"
      case `model` in
         ia64*) ostype="HP-UX_ia64" ;;
      esac
   ;;
   Darwin) ostype="Darwin_ix86"
           systype=`uname -srp`
      case `arch` in
         ppc*) ostype="Darwin_ppc" ;;
      esac
   ;;
   SunOS) systype=`uname -sri` ;;
   *)     systype=`uname -sr` ;;
esac
#
if [ ! -d "$VRAND_PATH" ]; then
   what=`basename "$0"`
   where=`dirname "$0"`
   here=`pwd`
   test x"$where" = x. && where="$here"
   case $where in
      /*) : ;;
      *) where="$here/$where" ;;
   esac
   while [ -L "$where/$what" ]; do
      ls=`/bin/ls -l "$where/$what"`
      cmd=`expr "$ls" : ".*-> \(.*\)"`
      what=`basename "$cmd"`
      newwhere=`dirname "$cmd"`
      test x"$newwhere" = x. && newwhere="$where"
      case $newwhere in
         /*) : ;;
         *) newwhere="$where/$newwhere" ;;
      esac
      where="$newwhere"
   done
   case $where in
      */vrand/bin) 
         VRAND_PATH=`expr "$where" : "\(.*\)/bin"`
      ;;
      *) printf "Error: Genesis was not properly installed!
       Edit the genesis script and set the variable \"VRAND_PATH\"
       to the full path to the vrand directory.
" >&2
         exit 1
      ;;
   esac
fi
#
#  standard name for the genesis executable
#
genesis_x="$VRAND_PATH/$gendir/$ostype/genesis.x"
#
#  name for the genesis 32-bit executable
#  (only for systems that have both 32-bit and 64-bit)
#
genesis_x_32="$VRAND_PATH/$gendir/$ostype/genesis32.x"
genesis_x_64="$genesis_x"
#
if [ x"$ostype" = xLinux_ix86 ]; then
   LD_LIBRARY_PATH_32="$VRAND_PATH/$gendir/$ostype/lib32:$LD_LIBRARY_PATH"
   LD_LIBRARY_PATH_64="$VRAND_PATH/$gendir/$ostype/lib64:$LD_LIBRARY_PATH"
   case `uname -m` in
      x86_64) 
        LD_LIBRARY_PATH="$LD_LIBRARY_PATH_64"
        ;;
      *) genesis_x="$genesis_x_32"
        LD_LIBRARY_PATH="$LD_LIBRARY_PATH_32"
        ;;
   esac
   export LD_LIBRARY_PATH
fi
if [ x"$ostype" = xLinux_ia64 ]; then
   LD_LIBRARY_PATH="$VRAND_PATH/$gendir/$ostype/lib:$LD_LIBRARY_PATH"
   export LD_LIBRARY_PATH
fi
#
if [ x"$GENESIS_LENVEC" = "xZZZgenesis_lenvecZZZ" ]; then
   printf "Error: Genesis was not properly installed!
       Edit the genesis script and set the variable \"GENESIS_LENVEC\"
       to the amount of memory (in words) GENESIS should use.
" >&2
   exit 1
fi
if [ ! -x "$genesis_x" ]; then
   printf "Error: The Genesis executable was not found!
       Check the setting of the \"VRAND_PATH\" variable in the genesis script.
" >&2
   exit 1
fi
#
sol=""
files=""
project=""
manuals=""
diag=""
dirall=""
iobuff=""
restart=""
runmode=""
policy=""
while [ $# != 0 ];
do
   case $1 in
      '"'*'"') arg=`expr "$1" : ".\(.*\)."`
      ;;
      *) arg="$1"
      ;;
   esac
   case "$arg" in
      -d) MakeDiff=1;;
      +d|-nod) MakeDiff=0;;
      -e) ShowErrors=1;;
      +e|-noe) ShowErrors=0;;
      -v) Verbose=1;;
      +v|-nov) Verbose=0;;
      -old) SaveOldOut=10;;
      -old=*) SaveOldOut=`expr "$arg" : "-old=\(.*\)"`;;
      -noold) SaveOldOut=0;;
      -diag) diag="$2"
             if [ $# -gt 1 ]; then shift; fi
          ;;
      -diag=*) diag=`expr "$arg" : "-diag=\(.*\)"`
          ;;
      -dirall) dirall="$2"
             if [ $# -gt 1 ]; then shift; fi
          ;;
      -dirall=*) dirall=`expr "$arg" : "-dirall=\(.*\)"`
          ;;
      -iobuff) iobuff="$2"
             if [ $# -gt 1 ]; then shift; fi
          ;;
      -iobuff=*) iobuff=`expr "$arg" : "-iobuff=\(.*\)"`
          ;;
      -restart) restart="$2"
             if [ $# -gt 1 ]; then shift; fi
          ;;
      -restart=*) restart=`expr "$arg" : "-restart=\(.*\)"`
          ;;
      -check) runmode=1
          ;;
      -anal*) runmode=2
          ;;
      -sens*) runmode=3
          ;;
      -sol) sol="$2"
             if [ $# -gt 1 ]; then shift; fi
          ;;
      -sol=*) sol=`expr "$arg" : "-sol=\(.*\)"`
          ;;
      -L|-l) if expr "$2" \* 1000000 > /dev/null 2>&1; then
             GENESIS_LENVEC="${2}000000"
             if [ $# -gt 1 ]; then shift; fi
          else
             Usage
             exit 1
          fi
          ;;
      -lenvec) lvwds="$2"
             if [ $# -gt 1 ]; then shift; fi
          case "$lvwds" in
          *M|*m) GENESIS_LENVEC=`expr "$lvwds" : "\(.*\)."`000000
             ;;
          *K|*k) GENESIS_LENVEC=`expr "$lvwds" : "\(.*\)."`000
             ;;
          *G|*g) GENESIS_LENVEC=`expr "$lvwds" : "\(.*\)."`000000000
             ;;
          *) GENESIS_LENVEC="$lvwds"
             ;;
          esac
          ;;
      -lenvec=*) lvwds=`expr "$arg" : "-lenvec=\(.*\)"`
          case "$lvwds" in
          *M|*m) GENESIS_LENVEC=`expr "$lvwds" : "\(.*\)."`000000
             ;;
          *K|*k) GENESIS_LENVEC=`expr "$lvwds" : "\(.*\)."`000
             ;;
          *G|*g) GENESIS_LENVEC=`expr "$lvwds" : "\(.*\)."`000000000
             ;;
          *) GENESIS_LENVEC="$lvwds"
             ;;
          esac
          ;;
      -L*|-l*) lvwds=`expr "$arg" : "-.\(.*\)"`
          if expr "$lvwds" \* 1000000 > /dev/null 2>&1; then
             GENESIS_LENVEC="${lvwds}000000"
          else
             Usage
             exit 1
          fi
          ;;
      -T|-t|-threads) GENESIS_THREADS="$2"
             if [ $# -gt 1 ]; then shift; fi
          ;;
      -threads=*) GENESIS_THREADS=`expr "$arg" : "-threads=\(.*\)"`
          ;;
      -T*|-t*) GENESIS_THREADS=`expr "$arg" : "-.\(.*\)"`
          ;;
      -policy) policy="$2"
             if [ $# -gt 1 ]; then shift; fi
          ;;
      -policy=*) policy=`expr "$arg" : "-policy=\(.*\)"`
          ;;
      -P|-p) project="$2"
             if [ $# -gt 1 ]; then shift; fi
          ;;
      -P*|-p*) project=`expr "$arg" : "-.\(.*\)"`
          ;;
      -32) 
          test -x "$genesis_x_32" && genesis_x="$genesis_x_32"
          test x"$LD_LIBRARY_PATH_32" != x && LD_LIBRARY_PATH="$LD_LIBRARY_PATH_32"
          ;;
      -64) 
          test -x "$genesis_x_64" && genesis_x="$genesis_x_64"
          test x"$LD_LIBRARY_PATH_64" != x && LD_LIBRARY_PATH="$LD_LIBRARY_PATH_64"
          ;;
      -clean) 
          test -x $VRAND_PATH/bin/cleangen && exec $VRAND_PATH/bin/cleangen
          exit 1
          ;;
      -vol1|-Vol1|-VOL1)
          manuals="$manuals $VRAND_PATH/$gendir/manuals/volume1.pdf"
          ;;
      -vol2|-Vol2|-VOL2)
          manuals="$manuals $VRAND_PATH/$gendir/manuals/volume2.pdf"
          ;;
      -vol3|-Vol3|-VOL3)
          manuals="$manuals $VRAND_PATH/$gendir/manuals/volume3.pdf"
          ;;
      -vol4|-Vol4|-VOL4)
          manuals="$manuals $VRAND_PATH/$gendir/manuals/volume4.pdf"
          ;;
      -*|+*) Usage; exit 1;;
      *) files="$files \"$arg\""
         ;;
   esac
   shift
done
#
if [ x"$manuals" != x ]; then
   echo $ACROREAD $manuals
   exec $ACROREAD $manuals
fi
if [ x"$policy" != x ]; then
   case $policy in
      /*) : ;;
      *) policy="$VRAND_PATH/etc/$policy" ;;
   esac
   GENESIS_POLICY="$policy"
   export GENESIS_POLICY
fi
#
if [ -z "$files" ]; then
   for targ in /usr/java*/jre/bin/java /opt/java*/jre/bin/java /opt/jre*/bin/java /opt/jdk*/jre/bin/java; do
      if [ "x$JAVA" = x -a -f "$targ" ]; then
         JAVA="$targ"
      fi
   done
   if [ "x$JAVA" != x ]; then
      files="\""`$JAVA -jar "$VRAND_PATH/bin/ChooseFile.jar"`"\""
      Verbose=1
   fi
fi
#
if [ -z "$files" ]; then
   Usage
   exit 1
fi
# make sure VRAND_PATH is in the environment
export VRAND_PATH
# make sure GENESIS_LENVEC is in the environment
export GENESIS_LENVEC
# make sure GENESIS_THREADS is in the environment
export GENESIS_THREADS
#
if [ x"$sol" != x ]; then
   GENESIS_SOL="$sol"
   export GENESIS_SOL
fi
#
if [ x"$diag" != x ]; then
   GENESIS_DIAG="$diag"
   export GENESIS_DIAG
fi
#
if [ x"$dirall" != x ]; then
   GENESIS_DIRALL="$dirall"
   export GENESIS_DIRALL
fi
#
if [ x"$iobuff" != x ]; then
   GENESIS_IOBUFF="$iobuff"
   export GENESIS_IOBUFF
fi
#
if [ x"$restart" != x ]; then
   GENESIS_RESTART="$restart"
   export GENESIS_RESTART
fi
#
if [ x"$runmode" != x ]; then
   GENESIS_RUNMODE="$runmode"
   export GENESIS_RUNMODE
fi
#
if [ x"$Verbose" = x1 ]; then 
   printf "\n  Genesis $gendesc ($systype)\n"
   printf "  Default LENVEC = $GENESIS_LENVEC\n"
   printf "  Default THREADS = $GENESIS_THREADS\n"
fi
#
eval set $files
while [ $# != 0 ];
do
   file="$1"
   shift
   fdir=`dirname "$file"`
   file=`basename "$file"`
   fname=`expr "$file" : "\(.*\)\." \| "$file"`
   if [ "$fname" = "$file" ]; then
      fnpext="$file.$DAT"
   else
      fnpext="$file"
   fi
#
   olddir=`pwd`
   cd "$fdir"
#
   if [ "$fnpext" = "$fname.$OUT" ]; then
#
#     #  the input data file name cannot have ".$OUT" as the extension.
#
      printf "Error: Input data file $fnpext has an invalid extension.\n" >&2
#
   elif [ -f "$fnpext" ]; then
#
#     #  run genesis
#
      rotate "$fname.$OUT" "$SaveOldOut"
#
      if [ x"$Verbose" = x1 ]; then 
         if [ x"$fdir" = x. ]; then
            printf "
  Input file:  $fnpext
  Output file: $fname.$OUT\n\n"
         else
            printf "
  Input file:  $fdir/$fnpext
  Output file: $fdir/$fname.$OUT\n\n"
         fi
      fi

      pname="$project"
      test x"$pname" = x && pname="$fname"
#
   cat <<EOF1 > "$fname.$LOG"
Genesis $gendesc
----------------------------------------------------------------
Hostname:     $HOSTNAME
Platform:     $systype
Working dir:  `pwd`
Input file:   $fnpext
Output file:  $fname.$OUT
Project name: $pname
----------------------------------------------------------------
EOF1
printenvvar PATH            "$fname.$LOG"
printenvvar LD_LIBRARY_PATH "$fname.$LOG"
printenvvar VRAND_PATH      "$fname.$LOG"
printenvvar GENESIS_POLICY  "$fname.$LOG"
printenvvar GENESIS_LENVEC  "$fname.$LOG"
printenvvar GENESIS_THREADS "$fname.$LOG"
printenvvar OMP_NUM_THREADS "$fname.$LOG"
printenvvar GENESIS_SOL     "$fname.$LOG"
printenvvar GENESIS_IOBUFF  "$fname.$LOG"
printenvvar GENESIS_DIAG    "$fname.$LOG"
printenvvar GENESIS_DIRALL  "$fname.$LOG"
printenvvar GENESIS_RESTART "$fname.$LOG"
printenvvar GENESIS_RUNMODE "$fname.$LOG"
printenvvar GENESIS_EXTDIR  "$fname.$LOG"
   cat <<EOF2 >> "$fname.$LOG"
----------------------------------------------------------------
EOF2
#     Run Genesis
#
#     the Genesis executable always writes to $fname.out
#     if that is not desired then work around thusly
      workaround=""
      if [ x"$OUT" != xout ]; then
         if [ -f "$fname.out" ]; then
            workaround="$fname.sav$$"
            mv "$fname.out" "$workaround"
         fi
      fi
#
      printf "Genesis Started  `date +'%Y-%m-%d %H:%M:%S'`\n" >> "$fname.$LOG"
#
      "$genesis_x" "$fnpext" "$pname" 2>&1 | tee -a "$fname.$LOG" >&2
#
      printf "Genesis Finished `date +'%Y-%m-%d %H:%M:%S'`\n" >> "$fname.$LOG"
#
      if [ x"$OUT" != xout ]; then
         mv "$fname.out" "$fname.$OUT"
         if [ -n "$workaround" ]; then
            mv "$workaround" "$fname.out"
         fi
      fi
#
      if [ x"$ShowErrors" = x1 ]; then
         awk '/^  *ERROR MESSAGE/,/^$/' "$fname.$OUT"
      fi
#
      if [ -f "$fname.$OUT.0" -a x"$MakeDiff" = x1 ]; then
         diff -i "$fname.$OUT" "$fname.$OUT.0" > "$fname.$DIF"
         if [ ! -s "$fname.$DIF" ]; then
            rm "$fname.$DIF"
            if [ x"$Verbose" = x1 ]; then 
               printf "--- The output data is same as the last run\n"
            fi
         else
            if [ x"$Verbose" = x1 ]; then 
               ls -al "$fname.$OUT"
               ls -al "$fname.$OUT.0"
               ls -al "$fname.$DIF"
            fi
         fi
      fi
#
   else
#
#     #  input file does not exist - give error message
#
      printf "Error: File not found: $fdir/$fnpext\n" >&2
#
   fi
#
   cd "$olddir"
#
done
#
exit
